#
# spec file for package deepin-music-player
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2013-2021 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?is_opensuse}
    %define  distribution  openSUSE-Edition
%else
    %define  distribution  SUSE-Edition
%endif

Name:           deepin-music-player
Version:        6.2.18
Release:        1.8
Summary:        Deepin Music Player
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://github.com/linuxdeepin/deepin-music
Source0:        https://github.com/linuxdeepin/deepin-music/archive/%{version}/deepin-music-%{version}.tar.gz
# PATCH-FIX-UPSTREAM Fix-library-link.patch hillwood@opensuse.org - Fix library link
Patch0:         Fix-library-link.patch
%ifarch ppc ppc64 ppc64le s390 s390x
BuildRequires:  deepin-desktop-base
%else
BuildRequires:  deepin-manual
%endif
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5Network-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtdeclarative-devel
BuildRequires:  libqt5-qtmultimedia-devel
BuildRequires:  libqt5-qtsvg-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Codecs)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(dbusextended-qt5)
BuildRequires:  pkgconfig(dframeworkdbus)
BuildRequires:  pkgconfig(dtkcore)
BuildRequires:  pkgconfig(dtkgui)
BuildRequires:  pkgconfig(dtkwidget)
BuildRequires:  pkgconfig(gsettings-qt)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcue)
BuildRequires:  pkgconfig(libvlc)
BuildRequires:  pkgconfig(mpris-qt5)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(udisks2-qt5)
BuildRequires:  pkgconfig(xext)
%if 0%{?suse_version} <= 1500
BuildRequires:  qtdbusextended-devel < 3.1.2
BuildRequires:  qtmpris-devel < 3.1.2
%endif
Requires:       qt5integration
Provides:       deepin-music
Requires:       vlc
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Deepin Music Player is a music player backed by gstreamer, with
customizable UI, and featuring music search by Pinyin and Quanpin. It
supports colorful lyrics, online audio support and a "mini mode".

%lang_package

%prep
%autosetup -p1 -n deepin-music-%{version}
sed -i 's/Exec=deepin-music/Exec=env QT_QPA_PLATFORMTHEME=deepin deepin-music/g' \
src/music-player/data/deepin-music.desktop
sed -i '/CMAKE_INSTALL_VOICE_LIBDIR/s|/usr/lib|${CMAKE_INSTALL_LIBDIR}|' \
src/libmusic-plugin/CMakeLists.txt

%build
%cmake -DVERSION=%{version}-%{distribution} \
       -DAPP_VERSION=%{version}-%{distribution}
%make_build

%install
%cmake_install

find %{buildroot} -type f -name "*.a" -delete -print

# openSUSE does not provide deepin-aiassistant, the deepin-aiassistant plugin is invaild
rm -rf %{buildroot}%{_libdir}/deepin-aiassistant

%suse_update_desktop_file -r deepin-music Audio Player
%fdupes %{buildroot}%{_datadir}

%files
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md
%license LICENSE
%{_bindir}/deepin-music
%{_datadir}/applications/deepin-music.desktop
%{_datadir}/icons/hicolor/scalable/apps/deepin-music.svg
%{_datadir}/deepin-manual/manual-assets/application/deepin-music
# %dir %{_libdir}/deepin-aiassistant
# %dir %{_libdir}/deepin-aiassistant/serivce-plugins
# %{_libdir}/deepin-aiassistant/serivce-plugins/libmusic-plugin.so

%files lang
%defattr(-,root,root,-)
%{_datadir}/deepin-music

%changelog
* Thu Aug 25 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 6.2.18
  * Fix bugs
* Wed Jun 29 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 6.2.16
  * Fix bugs
* Mon May  9 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 6.2.13
  * Fix bugs
- Drop the deepin-aiassistant plugin, this is an invaild plugin in openSUSE
* Thu Apr 21 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 6.2.12
  * Fix bugs
* Fri Mar 25 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 6.2.11.4
  * Fix bugs
- Drop recompile-with-fPIC.patch, merged by upstream
* Mon Feb 21 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 6.2.8
  * Update translations
  * Fix bugs
* Fri Jan 14 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 6.2.1
  * Support wayland
  * Update translations
  * Update manual document
  * Fix bugs
* Thu Jul 29 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 6.1.7
  * Update translations
  * Fix bugs
- Drop fix-return-type.patch, merged by upstream
* Sun May 23 2021 Hillwood Yang <hillwood@opensuse.org>
- Stop owning directories provided by filesystem and other packages
  (every dir should only have one owner) (boo#1184786)
* Wed Apr 14 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 6.1.2
  * Add help documents
  * Fix bug
  * Use mpris-qt5
- Add Patches: fix-return-type.patch and recompile-with-fPIC.patch
- Drop deepin-music-Qt-5_15.patch, merged by upstream.
* Fri Jan 29 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 6.0.1.91
  * no longer output libraries
  * feature update
  * Switch backend to VLC
  * Use new dtk apis
  * Fix many bugs
- Fix library link, add Fix-library-link.patch
* Wed Aug 19 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Wed Jun 17 2020 Hillwood Yang <hillwood@opensuse.org>
- Support Qt 5.15, add deepin-music-Qt-5_15.patch
* Mon Feb 10 2020 Hillwood Yang <hillwood@opensuse.org>
- Need pkgconfig(xext) while build on Leap 15.2
* Sun Aug  4 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.1
  * Fix avoid show another window
  * init music app connection after init player
  * changed the player init order
  * able to use libav via ENABLE_LIBAV
  * Update translations
* Sat Jun 15 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.1.18
  * should showNormal() when onRaise triggered
* Wed Apr 24 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.1.17.1
  * Fix shuffle is not random
  * do init MPRIS first
  * Update missing i18n text in settings dialog
  * chore: auto pull translation files from transifex
  * chore: correct a typo
* Wed Apr  3 2019 Hillwood Yang <hillwood@opensuse.org>
- Fix lyrics don't work (boo#1131464).
  * Add libnetease-meta-search.so in filelist, it is not a developement file
  * Add deepin-music-player-rpmlintrc
* Tue Mar  5 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.1.15
  * Fix wrong path when last import path is empty
  * Fix avoid using dpkg-parsechangelog
  * Fix last opened path check
  * Fix avoid set a empty path to QFileDialog
  * support X-Deepin-Vendor
  * support the recent file spec
  * support sliber animation
  * auto resize progress
  * hide custom sort from menu
  * keep sound hint when clicked
  * sync progress on close
  * use DThemeManger
  * add manual id
  * add VERSION configure option to define app version
- Remove useless BuildRequires tags.
* Fri Dec 21 2018 hillwood@opensuse.org
- Update version to  3.1.7.2
  * Fix avoid set a empty path to QFileDialog
  * support X-Deepin-Vendor
  * support the recent file spec
  * Fix pull tx failed
  * Fix write datebase error
  * Fix extrend close button area
  * disable keyboardSearch
  * Fix refactor
  * Fix update mpris status
  * Fix dock not support group
  * fav status disappear
  * trash file with dde-file-manager dbus in flatpak
  * add missing depends gstreamer1.0-fluendo-mp3
  * Fix shortcut not work
* Fri Mar 23 2018 kasimir_@outlook.de
- Fix build in armv6l
* Fri Feb  9 2018 hillwood@opensuse.org
- Fix build for Leap 15.0
  * Set BuildRequires tag for python.
* Fri Nov 24 2017 hillwood@opensuse.org
- Update 3.1.7.2
  * Fix showNormal not work (bb22dc99)
  * Fix crash when selectNext on qt 5.9 (bed9d856)
  * Fix hidpi playing state (84783418)
  * Fix lyric text cut (1dbf4dc2)
  * Fix move qmediaplayer to main thread (3ce0ca3c)
  * Fix dialog style (cfc0db93)
  * Use deviceRatio in musicitemdelegate (f3a65085)
  * Enable drag progress bar (22f8916e)
  * Fix border pos (6fa9cc9e)
  * Set dialog flag error (ef200472)
  * Change footer bar cover mouse cursor (a4837dce)
  * Fix libdmusic install path (2d86199a)
  * Make dropdown show full text on ru locale (fcc58c97)
  * Stop next after continue error count >= 5 (e6127596)
  * Call dbus trash (b5d6fcb4)
  * Extern footer progress (3459625e)
  * All use svg (a942c308)
  * Use dbus call filemanager (e276e636)
  * Remove dtk2 workaround (0eb1ee32)
  * Use dtk DWaterProgress (6109ffee)
  * Add hidpi support (107e5987)
- Drop deepin-tool-kit
- Drop libdui
* Thu Sep 28 2017 hillwood@opensuse.org
- Fix build in armv7l.
* Wed Sep 27 2017 hillwood@opensuse.org
- Update to 3.1.6
  * Update deepin-tool-kit
  * Use QtAV
  * Use dtkwidget
  * Use libcue
- Drop deepin-music-dui.patch, merged by upstream.
* Wed Mar 15 2017 i@marguerite.su
- Fix capitalized Summary
- Use 'rsvg-view' to produce multi-sized png icons from svg
  resource
- Fix the Unity play indicator groups in deepin-music.desktop
* Sun Feb 19 2017 jengelh@inai.de
- Replace totally useless description.
- Rename deepin-music-libnetease-meta-search1 again:
  it is a plugin, not a standard library!
- Fix RPM group selection. Do not call fdupes on root.
- Qt5 mkspecs belong into -devel subpackage.
* Sat Feb 18 2017 hillwood@opensuse.org
- Rename libnetease-meta-search as deepin-music-libnetease-meta-search1.
- Drop two devel packages.
* Thu Feb 16 2017 hillwood@opensuse.org
- Update to 3.0.1, fix boo#1023777.
  * Port python to C++ and QT5.
  * Port GStreamer to QT5Multimedia.
- add deepin-music-dui.patch.
  * Add lost pkgconfig item.
* Thu Nov 12 2015 hillwood@linuxfans.org
- Fix boo#954761
  * add python-Pillow as Requires.
- Add %%icon_theme_cache_post / %%icon_theme_cache_postun macro.
* Thu Jul 16 2015 i@marguerite.su
- update verison 2.90.0+git20150617.bb7889c
  * no upstream changelog
- clean specfile
  * upstream url: github.com/linuxdeepin/deepin-music
  * use upstream source instead of deepin distro's
  * avoid holding /usr/share/icons/hicolor
  * other minor fixes
* Tue Feb 17 2015 hillwood@linuxfans.org
- Update to 2.0git20150204.
  * add installation script
- remove deepin-music-player.desktop and deepin-music-player.png,
  upstream have included it.
* Sun Jul  6 2014 hillwood@linuxfans.org
- Add python-gstreamer-0_10 as Requires.
* Mon May 26 2014 hillwood@linuxfans.org
- Update to 2.0git20140505.
  Feature update.
* Thu Aug 15 2013 hillwood@linuxfans.org
- add deepin-gsettings as Requires
* Wed Aug 14 2013 hillwood@linuxfans.org
- update to 2.0git20130802
  * upsteam did not provide changlog
* Mon Apr 29 2013 hillwood@linuxfans.org
- update to 1.0.1git20130330(2.0 Alpha)
  * fix bugs
* Tue Mar 19 2013 douglarek@outlook.com
- Bug fix
  * fix bnc#808258
* Sun Feb 24 2013 kaji331@hotmail.com
- fix require python-cddb to python-CDDB
* Wed Feb  6 2013 hillwood@linuxfans.org
- update to 1.0.1git20130125(2.0 Alpha)
  * add plugins support
  * add mini mode
  * more media formats support
* Tue Jan  8 2013 douglarek@outlook.com
- Add runtime dependence: python-gtk
* Wed Sep 26 2012 hillwood@linuxfans.org
- update to 1.0.1git20120911
- fix bnc#778659
- more changlog please see http://goo.gl/WCVGo
* Tue Sep  4 2012 hillwood@linuxfans.org
- license update: GPL-3.0+
* Tue Sep  4 2012 hillwood@linuxfans.org
- add python-chardet , python-imaging and python-xlib as require
  packages.
* Sun Sep  2 2012 hillwood@linuxfans.org
- Initial package 1.0git20120716
  Init.
  Implement logging to tracking events that happen.
  Implement a basic configuration.
  Use listen-music-player play kernel, and thank him for his.
  Determine the Audio file type is supported.
  Add Universal encoding detector of the chardet.
